| DIVE | R Documentation |
The DIVE package is an approach to integration and interactive visual exploration of linked datasets and implements Shiny modules that can be run as stand-alone apps or part of a larger application.
matchApp
matrixApp
multiVUIR
dataHelperServer
(TO-DO)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.