| checkGEOplatform | R Documentation |
Check the GEO platform
checkGEOplatform(eset)
Within the broad dataset types, handled by checkGEOmetatype,
the different types of platforms that need to be considered for compatibility.
This excludes older platforms that are not one-channel array
for the "Expression profiling by array" type by using information in pData,
though there might be a better way to do this check.
Other checkGEO functions:
checkGEOmatrixfile(),
checkGEOmetatype(),
checkGEOwrapper()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.