customDatasetServer: Shiny module server for customized user-uploaded dataset

View source: R/customDataset.R

customDatasetServerR Documentation

Shiny module server for customized user-uploaded dataset

Description

An extension of dataUploadServer

Usage

customDatasetServer(
  id,
  customdata,
  defaultvalue = NULL,
  checkFun = NULL,
  informd = NULL,
  appdata = NULL
)

Arguments

id

Character ID for specifying namespace, see shiny::NS.

customdata

Optional, a named list containing name/label to be used in creating the key column.

defaultvalue

Optional, a default value to use.

checkFun

Optional, a custom check function for an additional layer of checking/modifying uploaded data. It should return a list containing message and result (result should be NULL when data fails checks).

informd

Relative path to the Rmarkdown file, whose contents will be displayed in the modal.

appdata

Optional, the path of one or more files that can be mock-uploaded. See details.

Details

The server extends dataUploadServer by appending to the uploaded data a custom data column with name specified by customdata and value filled from user input. This is conceptually the same as described in dataSubsetServer, with the only difference being that customdata is appended to a user-uploaded dataset instead of an existing subsettable dataset.

Value

A reactive data.table of the modified uploaded data.

See Also

Other customDataset functions: customDatasetInput()


avucoh/DIVE documentation built on Aug. 29, 2023, 6:02 p.m.