| dataFusion | R Documentation |
Concatenate two datasets given information on which columns are the same,
removing any NA values and keeping only the specified columns in the result
dataFusion(d1, d2, fuseon, sourcecol)
d1 |
A |
d2 |
A |
fuseon |
A named vector of the harmonized features, where the names are the features in d1 and elements are features in d2. |
sourcecol |
Character name of key column used to identify the row sources
(whether the row came from |
The datasets can have different names and dimensions, with fuseon acting
as the map. The implementation uses data.table and will output data.table.
This also doesn't check for same data type and will simply coerce as necessary.
A created sourcecol is conceptually the same as and uses idcol.
A data.table of the fused data.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.