| filterQuo | R Documentation |
Return a quosure of the appropriate filter expression for the given input component type to use later on
filterQuo(col, values, type)
col |
Filter column in |
values |
The filter value(s) in 'col'. |
type |
Type of input filter; only "range" is special and requires 'values' to be a 2-element vector. |
Most input components serve user selection/filter purposes;
sideFilterUI creates these input ui while this function
formulates the selection/filter expression from the input values.
In order to compose the appropriate expression,
we still need some info about the input component given by the parameter type,
e.g. whether it is "range" for a range sliderInput or something else.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.