| matchResultServer | R Documentation |
Carries out matching and returns a match result reactive object
matchResultServer(id, refdata, inputdata, params, sourcecol)
id |
Character ID for specifying namespace, see |
refdata |
Reactive refdata dataset as a |
inputdata |
Reactive |
params |
Reactive parameters data, e.g. from |
sourcecol |
Name for the source key column of the joined dataset. |
The module initializes a results reactive values list containing NULL values and
whenever new inputdata is passed in (clearing previous results).
The matching doesn't run until a valid params reactive object is provided,
which will call upon the underlying handler matchPair.
If successful, the module updates and returns the results reactive values list object
with results$params results$intermediate results$pair results$matchtable.
Though results$matchtable is rendered in this module's UI with its own download handler,
it and the rest are relevant data necessarily forwarded to matchPlotServer.
Reactive values containing params, intermediate results, pair, and matchtable.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.