| multiVCtrlServer | R Documentation |
Implement control hub logic that provides data and parameters for xVServer,
geneVServer and selectVServer
multiVCtrlServer(
id,
hdlist,
choices = DIVE::hdlistchoicesMake(hdlist),
cdata,
key = "ID",
preselect = NULL,
checkFun = NULL,
informd = system.file("info/ht_upload.Rmd", package = "DIVE")
)
id |
Character ID for specifying namespace, see |
hdlist |
A list of matrices representing high dimensional datasets; the names are used for |
choices |
Selection choices are by default created from automatic parsing of 'hdlist'. However, a manual list can be given,
which should be appropriate for passing to |
cdata |
A |
key |
Name of column that contains IDs in |
preselect |
Optional, pre-selected phenotype or clinical variables from |
checkFun |
Optional, a custom check function for an additional layer of checking/modifying uploaded data.
It should return a list containing message and result (result should be |
informd |
Relative path to the Rmarkdown file, whose contents will be displayed in the modal. |
The server logic handles sourcing of large expression datasets with three different methods:
Selecting from available pre-processed datasets.
User-uploaded data.
A beta (least-supported) method of retrieving datasets from GEO.
The data in cdata is supposed to be a phenotype or clinical
feature that one usually tries to correlate with expression data and can be numeric or categorical.
The module handles upload of phenotype/clinical data,
using a mutable version of cdata that appends user uploaded data.
A reactive values list containing the data matrix for the parameter
hdata
of the multiVServer module,
as well as parameters for geneVServer and selectVServer.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.