Arrange files containing raw sequence filenames and their corresponding MD5 hash. This files should be sorted as two column table. MD5SUM FILENAME
1 | raw_md5(extension = "md5.txt", subdirectory = "")
|
extension |
preferred file extension, default: md5.txt |
subdirectory |
subdirectory containing the files, within the current working directory. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.