| xVServer | R Documentation |
Integratively visualize a high-dimensional expression dataset with phenotype or clinical features through clustering, cross-selection and cross-comparison
xVServer(
id,
hdata,
cdata = reactive(NULL),
key = "ID",
selected = reactive(NULL),
height = 500,
returndata = NULL
)
id |
Character ID for specifying namespace, see |
hdata |
A numeric matrix with row and column names for heatmap representation. |
cdata |
Optional, a |
key |
Name of key column for |
selected |
A reactive vector used to subset the features (cols) of |
height |
Height for data plots. |
returndata |
A reactive object that can be used to return the local version of data in this module. |
The module is geared towards bioinformatics uses;
the data objects here can be compared to Biobase::ExpressionSet class object
where hdata corresponds to a (transposed) exprs matrix in the assayData slot
and cdata corresponds to the data in the phenoData slot.
The capabilities implemented are clustering (of samples by features only) and data subsetting.
The data subsetting of expression data works through a "local" selection,
which is simply created from column names of the hdata data matrix,
or through an alternative/global selection, which is whatever is passed into selected.
For alternative/global selection to work, the data must have an alternative index; see xVExprs.
Local selection takes precedences over alternative/global selection.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.