View source: R/customDataset.R
| customDatasetServer | R Documentation |
An extension of dataUploadServer
customDatasetServer(
id,
customdata,
defaultvalue = NULL,
checkFun = NULL,
informd = NULL,
appdata = NULL
)
id |
Character ID for specifying namespace, see |
customdata |
Optional, a named list containing name/label to be used in creating the key column. |
defaultvalue |
Optional, a default value to use. |
checkFun |
Optional, a custom check function for an additional layer of checking/modifying uploaded data.
It should return a list containing message and result (result should be |
informd |
Relative path to the Rmarkdown file, whose contents will be displayed in the modal. |
appdata |
Optional, the path of one or more files that can be mock-uploaded. See details. |
The server extends dataUploadServer by appending to the uploaded data
a custom data column with name specified by customdata and value filled from user input.
This is conceptually the same as described in dataSubsetServer,
with the only difference being that customdata is appended to a user-uploaded
dataset instead of an existing subsettable dataset.
A reactive data.table of the modified uploaded data.
Other customDataset functions:
customDatasetInput()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.